%define TDSVER 7.4

%define major      0
%define ct_major   4
%define sy_major   5
%define libtdsodbc %mklibname tdsodbc %{major}
%define libct      %mklibname ct %{ct_major}
%define libsybdb   %mklibname sybdb %{sy_major}
%define develname  %mklibname %{name} -d

Summary: 	An Open Source implementation of the tabular data stream protocol
Name: 		freetds
Version: 	1.4.12
Release: 	%mkrel 1
License: 	LGPLv2+ and GPLv2+
Group: 		System/Libraries
URL: 		https://www.freetds.org/
Source0:	ftp://ftp.freetds.org/pub/freetds/stable/freetds-%{version}.tar.gz
Patch0:		freetds-do_not_build_the_docs.diff
BuildRequires:	autoconf
BuildRequires:	automake
BuildRequires:	libtool
BuildRequires:	doxygen
BuildRequires:	docbook-style-dsssl
BuildRequires:	gettext-devel
BuildRequires:	pkgconfig(ncurses)
BuildRequires:	pkgconfig(readline)
BuildRequires:	pkgconfig(odbc) >= 2.0.0
BuildRequires:	pkgconfig(gnutls)
BuildRequires:	pkgconfig(krb5)
BuildRequires:	pkgconfig(libgcrypt)

%description
FreeTDS is a free (open source) implementation of Sybase's db-lib, ct-lib, and
ODBC libraries. Currently, dblib and ctlib are most mature. Both of these
libraries have several programs know to compile and run against them. ODBC is
just a roughed in skeleton, and not useful for real work.

This package is built with support for TDS version %{TDSVER}.

%package -n	%{libct}
Summary:	An Open Source implementation of the tabular data stream protocol
Group:		System/Libraries
Requires:	%{name} >= %{version}-%{release}

%description -n	%{libct}
This package contains a shared library for %{name} and is built with support
for TDS version %{TDSVER}.

%package -n	%{libsybdb}
Summary:	An Open Source implementation of the tabular data stream protocol
Group:		System/Libraries
Requires:	%{name} >= %{version}-%{release}

%description -n	%{libsybdb}
This package contains a shared library for %{name} and is built with support
for TDS version %{TDSVER}.

%package -n	%{libtdsodbc}
Summary:	Driver ODBC for unixODBC
Group:		System/Libraries
Provides:	%{name}-unixodbc

%description -n	%{libtdsodbc}
This package contains the ODBC driver build for unixODBC and is built with
support for TDS version %{TDSVER}.

%package -n	%{develname}
Summary:	Development libraries and header files for the FreeTDS library
Group:		Development/C
Requires:	%{libtdsodbc} = %{version}-%{release}
Requires:	%{libct} = %{version}-%{release}
Requires:	%{libsybdb} = %{version}-%{release}
Provides:	lib%{name}-devel = %{version}-%{release}
Provides:	%{name}-devel = %{version}-%{release}
Provides:	freetds_mssql-devel = %{version}-%{release}

%description -n	%{develname}
FreeTDS is a free (open source) implementation of Sybase's db-lib, ct-lib, and
ODBC libraries. Currently, dblib and ctlib are most mature. Both of these
libraries have several programs know to compile and run against them. ODBC is
just a roughed in skeleton, and not useful for real work.

This package is built with support for TDS version %{TDSVER}.

This package allows you to compile applications with freetds libraries.

%package doc
Summary:	User documentation for FreeTDS
Group:		Documentation

%description doc
The freetds-doc package contains the user guide and reference of FreeTDS and can
be installed even if FreeTDS main package is not installed

%prep
%setup -q
%patch0 -p1

find . -type d -perm 0700 -exec chmod 755 {} \;
find . -type f -perm 0555 -exec chmod 755 {} \;
find . -type f -perm 0444 -exec chmod 644 {} \;

for i in `find . -type d -name CVS`  `find . -type d -name .svn` `find . -type f -name .cvs\*` `find . -type f -name .#\*`; do
    if [ -e "$i" ]; then rm -rf $i; fi >&/dev/null
done

# lib64 fix
perl -pi -e "s|/lib\b|/%{_lib}|g" configure*

# perl path fix
find -type f | xargs perl -pi -e "s|/usr/local/bin/perl|%{_bindir}/perl|g"

# cleanup the initial source
sed -i 's/\r//' doc/tds_ssl.html
sed -i '1 s,#!.*/perl,#!%{__perl},' samples/*.pl doc/api_status.txt

find doc/ samples/ COPYING* -type f -print0 | xargs -0 chmod -x
find . -name "*.[ch]" -print0 | xargs -0 chmod -x

# cause to rebuild docs
# rm doc/reference/index.html
# rm doc/userguide/index.htm

%build
autoreconf -fis

%configure \
	--disable-dependency-tracking \
	--disable-rpath \
	--disable-static \
	--with-tdsver="%{TDSVER}" \
	--with-unixodbc="%{_prefix}" \
	--enable-msdblib \
	--enable-sybase-compat \
	--with-gnutls \
	--enable-krb5

%make_build

# DOCBOOK_DSL="`rpm -ql docbook-style-dsssl | grep html/docbook.dsl`"

# (oe) the test suite assumes you have access to a sybase/mssql database 
# server (tds_connect) and have a correct freedts config...
#make check

%install
install -d %{buildroot}/interfaces
install -d %{buildroot}%{_sysconfdir}/%{name}
install -d %{buildroot}%{_datadir}/%{name}-%{version}/samples
install -d %{buildroot}%{_mandir}/man1
install -d %{buildroot}%{_mandir}/man5

%make_install

find %{buildroot} -name '*.la' -delete

# keep this for now...
install -m0644 include/freetds/tds.h %{buildroot}%{_includedir}/

install -m0644 doc/*.1 %{buildroot}%{_mandir}/man1/
install -m0644 doc/*.5 %{buildroot}%{_mandir}/man5/

chmod +x %{buildroot}%{_libdir}/*.so
cp -a -f samples/* %{buildroot}%{_datadir}/%{name}-%{version}/samples/

mv %{buildroot}/interfaces %{buildroot}%{_datadir}/%{name}-%{version}/

pushd %{buildroot}%{_sysconfdir}/%{name}
    ln -sf ../..%{_datadir}/%{name}-%{version}/interfaces/
popd

#remove unwanted files
rm -rf %{buildroot}%{_sysconfdir}/locales.conf
rm -rf %{buildroot}%{_docdir}/%{name}*

%files
%doc AUTHORS.md ChangeLog NEWS.md README.md PWD
%license COPYING.txt
%config(noreplace) %{_sysconfdir}/freetds.conf
%config(noreplace) %{_sysconfdir}/pool.conf
%dir %{_datadir}/%{name}-%{version}
%{_bindir}/bsqldb
%{_bindir}/bsqlodbc
%{_bindir}/datacopy
%{_bindir}/defncopy
%{_bindir}/fisql
%{_bindir}/freebcp
%{_bindir}/osql
%{_bindir}/tdspool
%{_bindir}/tsql
%{_datadir}/%{name}-%{version}/interfaces
%{_sysconfdir}/%{name}/interfaces
%{_mandir}/man1/*
%{_mandir}/man5/*

%files -n %{libtdsodbc}
%license COPYING_LIB.txt
%{_libdir}/libtdsodbc.so.%{major}{,.*}

%files -n %{libct}
%license COPYING_LIB.txt
%{_libdir}/libct.so.%{ct_major}{,.*}

%files -n %{libsybdb}
%license COPYING_LIB.txt
%{_libdir}/libsybdb.so.%{sy_major}{,.*}

%files -n %{develname}
%doc TODO.md
%{_includedir}/*.h
%{_libdir}/*.so
%{_datadir}/%{name}-%{version}/samples

%files doc
%doc doc/images doc/userguide doc/reference


%changelog
* Tue Apr 23 2024 daviddavid <daviddavid> 1.4.12-1.mga10
+ Revision: 2060559
- new version: 1.4.12

* Sun Jan 21 2024 daviddavid <daviddavid> 1.4.10-1.mga10
+ Revision: 2033363
- new version: 1.4.10

* Mon Nov 27 2023 daviddavid <daviddavid> 1.4.7-1.mga10
+ Revision: 2009938
- new version: 1.4.7

* Wed Nov 01 2023 daviddavid <daviddavid> 1.4.6-1.mga10
+ Revision: 2003358
- new version: 1.4.6

* Fri Sep 01 2023 daviddavid <daviddavid> 1.3.20-1.mga10
+ Revision: 1982973
- new version: 1.3.20

* Sun Jan 08 2023 daviddavid <daviddavid> 1.3.16-1.mga9
+ Revision: 1931579
- new version: 1.3.16

* Sun Nov 13 2022 daviddavid <daviddavid> 1.3.14-1.mga9
+ Revision: 1906808
- new version: 1.3.14

* Fri Mar 18 2022 papoteur <papoteur> 1.3.9-1.mga9
+ Revision: 1798184
- Update to 1.3.9. Fix build by adding gettext-devel dependency

* Mon Jan 17 2022 mrambo3501 <mrambo3501> 1.3.6-1.mga9
+ Revision: 1768887
- version 1.3.6

* Fri Apr 23 2021 daviddavid <daviddavid> 1.2.20-1.mga9
+ Revision: 1718049
- new version: 1.2.20

* Thu Mar 04 2021 daviddavid <daviddavid> 1.2.18-1.mga9
+ Revision: 1697961
- new version: 1.2.18

* Sun Nov 29 2020 luigiwalser <luigiwalser> 1.1.40-2.mga8
+ Revision: 1650422
- rebuild for nettle

* Thu May 28 2020 daviddavid <daviddavid> 1.1.40-1.mga8
+ Revision: 1588333
- new version: 1.1.40

* Wed Apr 22 2020 daviddavid <daviddavid> 1.1.33-1.mga8
+ Revision: 1570632
- new version: 1.1.33

* Wed Feb 19 2020 umeabot <umeabot> 1.1.24-2.mga8
+ Revision: 1543925
- Mageia 8 Mass Rebuild

* Thu Jan 23 2020 daviddavid <daviddavid> 1.1.24-1.mga8
+ Revision: 1482383
- new version: 1.1.24
+ wally <wally>
- replace deprecated %%configure2_5x

* Sat Jan 04 2020 luigiwalser <luigiwalser> 1.1.20-2.mga8
+ Revision: 1475945
- rebuild for readline

* Mon Nov 11 2019 daviddavid <daviddavid> 1.1.20-1.mga8
+ Revision: 1459146
- new version: 1.1.20

* Sun Oct 06 2019 daviddavid <daviddavid> 1.1.16-1.mga8
+ Revision: 1449942
- new version: 1.1.16
- switch tdsver to 7.4 (7.0 cannot anymore be specified during configure as too insecure)

* Tue Oct 01 2019 daviddavid <daviddavid> 1.00.83-4.mga8
+ Revision: 1448676
- split out all libraries in their own sub-pkg as they should

* Tue Oct 01 2019 daviddavid <daviddavid> 1.00.83-3.mga8
+ Revision: 1448567
- rebuild for new nettle 3.5.1

* Sun Sep 23 2018 umeabot <umeabot> 1.00.83-2.mga7
+ Revision: 1297779
- Mageia 7 Mass Rebuild
+ kekepower <kekepower>
- Use new make macros

* Thu Mar 22 2018 kekepower <kekepower> 1.00.83-1.mga7
+ Revision: 1211291
- Update to version 1.00.83

* Tue Jan 02 2018 wally <wally> 0.95.87-2.mga7
+ Revision: 1189428
- rebuild for new readline

* Sat Feb 27 2016 oden <oden> 0.95.87-1.mga6
+ Revision: 979949
- 0.95.87

* Sat Feb 06 2016 umeabot <umeabot> 0.91-9.mga6
+ Revision: 940155
- Mageia 6 Mass Rebuild

* Wed Oct 15 2014 umeabot <umeabot> 0.91-8.mga5
+ Revision: 747367
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 0.91-7.mga5
+ Revision: 679352
- Mageia 5 Mass Rebuild

* Sat Oct 19 2013 umeabot <umeabot> 0.91-6.mga4
+ Revision: 533712
- Mageia 4 Mass Rebuild

* Wed Sep 04 2013 luigiwalser <luigiwalser> 0.91-5.mga4
+ Revision: 474939
- rpm no longer allows listing a symlink to a directory as a dir in files

* Fri Jan 11 2013 umeabot <umeabot> 0.91-4.mga3
+ Revision: 350950
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sun Oct 14 2012 ennael <ennael> 0.91-3.mga3
+ Revision: 305601
- Documentation group

* Thu Dec 08 2011 fwang <fwang> 0.91-2.mga2
+ Revision: 178856
- rebuild for new odbc

* Wed Sep 07 2011 tv <tv> 0.91-1.mga2
+ Revision: 140306
- new release
- new release (fixes CVE-2011-2964)
+ ahmad <ahmad>
- drop old/unneeded scriptlets
- imported package freetds


* Sun Jan 02 2011 Oden Eriksson <oeriksson@mandriva.com> 0.82-11mdv2011.0
+ Revision: 627571
- don't force the usage of automake1.7

* Sat Sep 18 2010 Funda Wang <fwang@mandriva.org> 0.82-10mdv2011.0
+ Revision: 579335
- add missing requires

* Sun Mar 14 2010 Oden Eriksson <oeriksson@mandriva.com> 0.82-9mdv2010.1
+ Revision: 519002
- rebuild

* Thu Sep 03 2009 Oden Eriksson <oeriksson@mandriva.com> 0.82-8mdv2010.0
+ Revision: 427840
- added P1 from fedora to fix build (libtool)
- fix build

  + Christophe Fergeau <cfergeau@mandriva.com>
    - rebuild

* Wed Feb 25 2009 Thierry Vignaud <tv@mandriva.org> 0.82-7mdv2009.1
+ Revision: 344804
- rebuild for new libreadline

* Sat Dec 20 2008 Oden Eriksson <oeriksson@mandriva.com> 0.82-6mdv2009.1
+ Revision: 316559
- rebuild

* Fri Sep 12 2008 Oden Eriksson <oeriksson@mandriva.com> 0.82-5mdv2009.0
+ Revision: 284184
- fix #31665 (Typo in summary and bad source url)

* Tue Jun 17 2008 Anssi Hannula <anssi@mandriva.org> 0.82-4mdv2009.0
+ Revision: 222182
- replace freetds_mssql subpackages

  + Pixel <pixel@mandriva.com>
    - do not call ldconfig in %%post/%%postun, it is now handled by filetriggers

* Thu May 15 2008 Oden Eriksson <oeriksson@mandriva.com> 0.82-3mdv2009.0
+ Revision: 207642
- whoops!
- add compat headers

* Thu May 08 2008 Oden Eriksson <oeriksson@mandriva.com> 0.82-2mdv2009.0
+ Revision: 204503
- rebuild
- 0.82
- added P0 to disable building the allready built docs

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

  + Thierry Vignaud <tv@mandriva.org>
    - kill re-definition of %%buildroot on Pixel's request

* Tue Sep 04 2007 Oden Eriksson <oeriksson@mandriva.com> 0.64-5mdv2008.0
+ Revision: 79215
- sync with freetds-0.64-7.fc8.src.rpm to make it build the docs
- new devel naming


* Wed Oct 11 2006 Oden Eriksson <oeriksson@mandriva.com>
+ 2006-10-10 10:38:53 (63317)
- rebuild

* Wed Oct 11 2006 Oden Eriksson <oeriksson@mandriva.com>
+ 2006-10-10 10:37:57 (63316)
- Import freetds

* Tue Jul 18 2006 Oden Eriksson <oeriksson@mandriva.com> 0.64-2mdv2007.1
- rebuild

* Mon Jul 03 2006 Oden Eriksson <oeriksson@mandriva.com> 0.64-2mdv2007.0
- 0.64 (Major feature enhancements)

* Tue May 16 2006 Oden Eriksson <oeriksson@mandriva.com> 0.64-1.RC2.1mdk
- 0.64RC2

* Fri Oct 21 2005 Oden Eriksson <oeriksson@mandriva.com> 0.64-0.20051020.1mdk
- new snap (20051020)

* Fri Sep 02 2005 Oden Eriksson <oeriksson@mandriva.com> 0.64-0.20050831.1mdk
- used a snap in an attempt to close #17272

* Fri May 06 2005 Oden Eriksson <oeriksson@mandriva.com> 0.63-3mdk
- rebuilt with gcc4

* Sun Apr 10 2005 Oden Eriksson <oeriksson@mandrakesoft.com> 0.63-2mdk
- added one lib64 fix

* Thu Mar 31 2005 Oden Eriksson <oeriksson@mandrakesoft.com> 0.63-1mdk
- 0.63
- use the %%mkrel macro

* Fri Feb 04 2005 Oden Eriksson <oeriksson@mandrakesoft.com> 0.62.4-5mdk
- rebuilt against new readline

* Mon Jan 03 2005 Oden Eriksson <oeriksson@mandrakesoft.com> 0.62.4-4mdk
- fix deps

* Mon Jan 03 2005 Oden Eriksson <oeriksson@mandrakesoft.com> 0.62.4-3mdk
- libifiction (why hasn't this been done before?)

* Wed Jul 14 2004 Oden Eriksson <oeriksson@mandrakesoft.com> 0.62.4-2mdk
- make it compile on 10.0 too

* Sat Jul 03 2004 Oden Eriksson <oeriksson@mandrakesoft.com> 0.62.4-1mdk
- 0.62.4

* Tue Jun 15 2004 Oden Eriksson <oeriksson@mandrakesoft.com> 0.62.3-2mdk
- rebuild

* Thu May 06 2004 Oden Eriksson <oeriksson@mandrakesoft.com> 0.62.3-1mdk
- 0.62.3
- merge spec file stuff from the provided spec file
- fix deps
- misc spec file fixes

